@@ -2,7 +2,7 @@
 from blockdiag.noderenderer.box import Box
 from blockdiag.noderenderer import install_renderer
 from blockdiag.utils.XY import XY
-from blockdiag.imagedraw.SVGdraw import pathdata
+from blockdiag.imagedraw.simplesvg import pathdata
 
 
 class QB(Box):
